# frozen_string_literal: true

module Roqua::CsvExport
  # For each metadata key in export_versions, define a function to get the value for it for a given response.
  module MetaData
    extend self

    def anonymous(response)
      response.anonymous ? 'anonymous' : ''
    end

    def birth_year(response)
      nil # deprecated
    end

    def compl_by(response)
      return nil unless response.completed_at
      return nil if response.anonymous && response.entered_by&.external_identifier.nil?

      response.entered_by&.external_identifier || response.dossier.external_identifier
    end

    def completed_at(response)
      response.completed_at
    end

    def date(response)
      response.observation_time
    end

    def emailed_at(response)
      nil # deprecated
    end

    def gender(response)
      nil #deprecated
    end

    def hide_pii_from_researchers(response)
      response.hide_pii_from_researchers ? "hide" : "show"
    end

    def hide_values_from_professionals(response)
      response.hide_values_from_professionals ? "hide" : "show"
    end

    def id(response)
      response.id
    end

    def invited_at(response)
      nil # deprecated
    end

    def location(response)
      response.team&.name
    end

    def measurement(response)
      response.measurement&.name
    end

    def non_response(response)
      response.non_response&.id
    end

    def notes(response)
      response.notes
    end

    def open_from(response)
      response.open_from
    end

    def patient_id(response)
      return nil if response.anonymous

      response.dossier.external_identifier
    end

    def project(response)
      nil # deprecated
    end

    def protocol(response)
      response.measurement&.protocol&.name
    end

    def respondent_id(response)
      return nil if response.anonymous

      response.respondent&.id
    end

    def respondent_label(response)
      response.respondent&.label || 'Medewerker'
    end

    def respondent_type(response)
      response.respondent&.type || 'profess'
    end

    def roqua_id(response)
      nil # deprecated
    end

    def started_at(response)
      response.started_at
    end

    def variant(response)
      response.questionnaire_variant
    end
  end
end
