# frozen_string_literal: true

module Roqua::CsvExport::Models
  class Response < Sequel::Model
    many_to_one :dossier
    many_to_one :measurement
    many_to_one :questionnaire
    many_to_one :team
    many_to_one :entered_by, class: Professional
    many_to_one :respondent
    many_to_one :non_response
    one_to_many :response_flags
    one_to_many :response_scores
    one_to_many :response_textvars
    one_to_many :response_values

    # List of answers to questions.
    # @return [Hash{String=>String}] !{'v_1' => '3', ...}
    def variable_hash
      @variable_hash ||= response_values.each_with_object({}) do |response_value, hash|
        hash[response_value.question_key] = response_value.data
      end
    end

    # List of calculated scores.
    # @return [Hash{String=>Hash{String}}] !{'tot' => {'value' => '15', ...}, ...}
    def score_hash
      @response_score_hash ||= response_scores.each_with_object({}) do |response_score, hash|
        (hash[response_score.score_key] ||= {})[response_score.score_subkey] = response_score.data
      end
    end

    # Get answer belonging to given key.
    # @param key [String] e.g. "v_1"
    # @return [String] The value for specified question_key
    def variable(key)
      variable_hash[key]
    end

    # Retrieve a score value. main value for a score will usually have sub_key "value".
    # @param key [String] e.g. "tot"
    # @param sub_key [String] e.g. "value" or "interpretation"
    # @return [String]
    def score(key, sub_key)
      score_hash.dig(key, sub_key)
    end

    # @param key [String] prepended with questionnaire_key
    # @return [String]
    def flag(key)
      response_flags.find { |response_flag| response_flag.key == key }.value
    end

    # @param key [String] prepended with questionnaire_key.
    # @return [String]
    def textvar(key)
      response_textvars.find { |response_textvar| response_textvar.key == key }.value
    end
  end
end
